package fe

import (
	"math/rand"
	"net"
	"strings"
)

// Filter a list of IP addresses by protocol.
func filterIpByProto(ips []net.IP, v6 bool) []net.IP {
	var candidates []net.IP
	for _, ip := range ips {
		isIPv6 := (ip.To4() == nil)
		if (isIPv6 && v6) || (!isIPv6 && !v6) {
			candidates = append(candidates, ip)
		}
	}
	return candidates
}

// Pick a random IP for the specified proto.
func randomIpByProto(ips []net.IP, v6 bool) net.IP {
	candidates := filterIpByProto(ips, v6)
	if len(candidates) > 0 {
		return candidates[rand.Intn(len(candidates))]
	}
	return nil
}

// Return an appropriate name for a metric, given an IP address.
func ipToMetric(ip net.IP) string {
	return strings.Replace(ip.String(), ".", "_", -1)
}
